==> ksystemlog_19.12.3.orig.tar.xz: ksystemlog-19.12.3/src/modes/samba/sambaAccessLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef SAMBA_ACCESS_LOG_MODE_H
#define SAMBA_ACCESS_LOG_MODE_H

/**
 * Samba Access Log Mode Identifier
 */
#define SAMBA_ACCESS_LOG_MODE_ID "sambaAccessLogMode"

/**
 * Samba Access Log Icon
 */
#define SAMBA_ACCESS_MODE_ICON "preferences-system-network-server-share-windows"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class SambaConfiguration;
class SambaConfigurationWidget;
class SambaItemBuilder;

class SambaAccessLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit SambaAccessLogMode(QSharedPointer<SambaConfiguration> &sambaConfiguration,
                                SambaConfigurationWidget *sambaConfigurationWidget,
                                SambaItemBuilder *itemBuilder);

    ~SambaAccessLogMode();

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;

    QList<LogFile> createLogFiles() override;
};

#endif // _SAMBA_ACCESS_LOG_MODE_H

==> ksystemlog-21.04.3.tar.xz: ksystemlog-21.04.3/src/modes/samba/sambaAccessLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef SAMBA_ACCESS_LOG_MODE_H
#define SAMBA_ACCESS_LOG_MODE_H

/**
 * Samba Access Log Mode Identifier
 */
#define SAMBA_ACCESS_LOG_MODE_ID "sambaAccessLogMode"

/**
 * Samba Access Log Icon
 */
#define SAMBA_ACCESS_MODE_ICON "preferences-system-network-server-share-windows"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class SambaConfiguration;
class SambaConfigurationWidget;
class SambaItemBuilder;

class SambaAccessLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit SambaAccessLogMode(QSharedPointer<SambaConfiguration> &sambaConfiguration,
                                SambaConfigurationWidget *sambaConfigurationWidget,
                                SambaItemBuilder *itemBuilder);

    ~SambaAccessLogMode() override;

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;

    QVector<LogFile> createLogFiles() override;
};

#endif // _SAMBA_ACCESS_LOG_MODE_H
